@@ -75,7 +75,9 @@ ggit_branch_delete (GgitBranch  *branch,
  * ggit_branch_move:
  * @branch: a #GgitBranch.
  * @new_branch_name: target name of the branch once the move is performed; this name is validated for consistency.
- * @flags: a GgitCreateFlags.
+ * @flags: a #GgitCreateFlags.
+ * @signature: a #GgitSignature used to populate the reflog entry.
+ * @log_message: The one line long message to be appended to the reflog.
  * @error: a #GError for error reporting, or %NULL.
  *
  * Moves/renames an existing branch reference.
@@ -86,6 +88,8 @@ GgitBranch *
 ggit_branch_move (GgitBranch       *branch,
                   const gchar      *new_branch_name,
                   GgitCreateFlags   flags,
+                  GgitSignature    *signature,
+                  const gchar      *log_message,
                   GError          **error)
 {
 	git_reference *out;
@@ -101,7 +105,9 @@ ggit_branch_move (GgitBranch       *branch,
 	ret = git_branch_move (&out,
 	                       _ggit_native_get (branch),
 	                       new_branch_name,
-	                       force ? 1 : 0);
+	                       force ? 1 : 0,
+	                       _ggit_native_get (signature),
+	                       log_message);
 
 	if (ret != GIT_OK)
 	{
