@@ -47,9 +47,14 @@ G_DEFINE_TYPE_EXTENDED (GgitPush, ggit_push, GGIT_TYPE_NATIVE,
 
 
 static void
-ggit_push_finalize (GObject *object)
+ggit_push_dispose (GObject *object)
 {
-	G_OBJECT_CLASS (ggit_push_parent_class)->finalize (object);
+	GgitPushPrivate *priv;
+
+	priv = GGIT_PUSH (object)->priv;
+	g_clear_object (&priv->remote);
+
+	G_OBJECT_CLASS (ggit_push_parent_class)->dispose (object);
 }
 
 static void
@@ -63,7 +68,7 @@ ggit_push_get_property (GObject    *object,
 	switch (prop_id)
 	{
 		case PROP_REMOTE:
-			g_value_set_boxed (value, priv->remote);
+			g_value_set_object (value, priv->remote);
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -82,7 +87,7 @@ ggit_push_set_property (GObject      *object,
 	switch (prop_id)
 	{
 		case PROP_REMOTE:
-			priv->remote = g_value_get_boxed (value);
+			priv->remote = g_value_dup_object (value);
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -95,18 +100,18 @@ ggit_push_class_init (GgitPushClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	object_class->finalize = ggit_push_finalize;
+	object_class->dispose = ggit_push_dispose;
 	object_class->get_property = ggit_push_get_property;
 	object_class->set_property = ggit_push_set_property;
 
 	g_object_class_install_property (object_class,
 	                                 PROP_REMOTE,
-	                                 g_param_spec_boxed ("remote",
-	                                                       "Remote",
-	                                                       "The remote associated with this push",
-	                                                       GGIT_TYPE_REMOTE,
-	                                                       G_PARAM_READWRITE |
-	                                                       G_PARAM_CONSTRUCT_ONLY));
+	                                 g_param_spec_object ("remote",
+	                                                      "Remote",
+	                                                      "The remote associated with this push",
+	                                                      GGIT_TYPE_REMOTE,
+	                                                      G_PARAM_READWRITE |
+	                                                      G_PARAM_CONSTRUCT_ONLY));
 
 	g_type_class_add_private (object_class, sizeof (GgitPushPrivate));
 }
@@ -204,28 +209,108 @@ ggit_push_add_refspec (GgitPush     *push,
 	}
 }
 
+typedef struct
+{
+	GgitPushProgress  *progress;
+	GError           **error;
+} PushProgressInfo;
+
+static gint
+packbuilder_progress_wrapper (gint     stage,
+                              guint    current,
+                              guint    total,
+                              gpointer payload)
+{
+	PushProgressInfo *info;
+	info = payload;
+
+	if (!ggit_push_progress_packbuilder_progress (info->progress,
+	                                              stage,
+	                                              current,
+	                                              total,
+	                                              info->error))
+	{
+		return GIT_ERROR;
+	}
+
+	return GIT_OK;
+}
+
+static gint
+transfer_progress_wrapper (guint    current,
+                           guint    total,
+                           gsize    bytes,
+                           gpointer payload)
+{
+	PushProgressInfo *info;
+	info = payload;
+
+	if (!ggit_push_progress_transfer_progress (info->progress,
+	                                           current,
+	                                           total,
+	                                           bytes,
+	                                           info->error))
+	{
+		return GIT_ERROR;
+	}
+
+	return GIT_OK;
+}
+
 /**
  * ggit_push_finish:
  * @push: a #GgitPush.
+ * @progress: (allow-none): a #GgitPushProgress, or %NULL.
  * @error: a #GError for error reporting, or %NULL.
  *
  * Actually push all given refspecs.
  */
-void
-ggit_push_finish (GgitPush  *push,
-                  GError   **error)
+gboolean
+ggit_push_finish (GgitPush          *push,
+                  GgitPushProgress  *progress,
+                  GError           **error)
 {
 	gint ret;
 
-	g_return_if_fail (GGIT_IS_PUSH (push));
-	g_return_if_fail (error == NULL || *error == NULL);
+	PushProgressInfo info = {0,};
+
+	g_return_val_if_fail (GGIT_IS_PUSH (push), FALSE);
+	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
+	info.progress = progress;
+	info.error = error;
+
+	if (progress != NULL)
+	{
+		git_push_set_callbacks (_ggit_native_get (push),
+		                        packbuilder_progress_wrapper,
+		                        &info,
+		                        transfer_progress_wrapper,
+		                        &info);
+	}
 
 	ret = git_push_finish (_ggit_native_get (push));
 
+	if (progress != NULL)
+	{
+		git_push_set_callbacks (_ggit_native_get (push),
+		                        NULL,
+		                        NULL,
+		                        NULL,
+		                        NULL);
+	}
+
 	if (ret != GIT_OK)
 	{
-		_ggit_error_set (error, ret);
+		if (error && *error == NULL)
+		{
+			_ggit_error_set (error, ret);
+		}
+
+		return FALSE;
 	}
+
+	return TRUE;
 }
 
 /**
