@@ -21,7 +21,7 @@
 #ifndef __GGIT_TREE_H__
 #define __GGIT_TREE_H__
 
-#include <git2/tree.h>
+#include <git2.h>
 #include <libgit2-glib/ggit-object.h>
 #include <libgit2-glib/ggit-types.h>
 #include <libgit2-glib/ggit-tree-entry.h>
@@ -84,9 +84,6 @@ void           ggit_tree_walk           (GgitTree              *tree,
                                          gpointer               user_data,
                                          GError               **error);
 
-GgitTreeBuilder *ggit_tree_create_builder (GgitTree  *tree,
-                                           GError   **error);
-
 G_END_DECLS
 
 #endif /* __GGIT_TREE_H__ */
