@@ -262,4 +262,7 @@ ASSERT_ENUM (GGIT_DIFF_FIND_EXACT_MATCH_ONLY,           GIT_DIFF_FIND_EXACT_MATC
 ASSERT_ENUM (GGIT_DIFF_BREAK_REWRITES_FOR_RENAMES_ONLY, GIT_DIFF_BREAK_REWRITES_FOR_RENAMES_ONLY);
 ASSERT_ENUM (GGIT_DIFF_FIND_REMOVE_UNMODIFIED,          GIT_DIFF_FIND_REMOVE_UNMODIFIED);
 
+ASSERT_ENUM (GGIT_DIFF_FORMAT_EMAIL_NONE, GIT_DIFF_FORMAT_EMAIL_NONE);
+ASSERT_ENUM (GGIT_DIFF_FORMAT_EMAIL_EXCLUDE_SUBJECT_PATCH_MARKER, GIT_DIFF_FORMAT_EMAIL_EXCLUDE_SUBJECT_PATCH_MARKER);
+
 /* ex:set ts=8 noet: */
